@@ -213,7 +213,7 @@ up_device_wup_parse_command (UpDeviceWup *wup, const gchar *data)
 	/* replace the first ';' char with a NULL if it exists */
 	length = strlen (packet);
 	for (i=0; i<length; i++) {
-		if (packet[i] < 0x20 && packet[i] > 0x7e)
+		if (packet[i] < 0x20 || packet[i] > 0x7e)
 			packet[i] = '?';
 		if (packet[i] == ';') {
 			packet[i] = '\0';
@@ -388,7 +388,6 @@ static gboolean
 up_device_wup_refresh (UpDevice *device)
 {
 	gboolean ret = FALSE;
-	GTimeVal timeval;
 	gchar *data = NULL;
 	UpDeviceWup *wup = UP_DEVICE_WUP (device);
 
@@ -407,8 +406,7 @@ up_device_wup_refresh (UpDevice *device)
 	}
 
 	/* reset time */
-	g_get_current_time (&timeval);
-	g_object_set (device, "update-time", (guint64) timeval.tv_sec, NULL);
+	g_object_set (device, "update-time", (guint64) g_get_real_time () / G_USEC_PER_SEC, NULL);
 
 out:
 	g_free (data);
